"""Dates and times

This is an extension of :mod:`datetime`.

"""

__version__ = "0.2.2"
__copyright__ = "Copyright (C) 2014 Ivan D Vasin"
__credits__ = ["Ivan D Vasin"]
__maintainer__ = "Ivan D Vasin"
__email__ = "nisavid@gmail.com"
__docformat__ = "restructuredtext"

from ._conversion import *
from ._misc import *
from ._str import *
from ._tz import *
